==> haskell-floskell-0.10.8-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-IIyyg5dQ9eA95eQiELMI5s
key:                  floskell-0.10.8-IIyyg5dQ9eA95eQiELMI5s
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  abc9e862adeef9fbdbe4ca5f8f96ba78
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-IIyyg5dQ9eA95eQiELMI5s
depends:
    aeson-2.1.2.1-7MxCVi0kerx5YLDSk2pLUu
    attoparsec-0.14.4-6bGZjP6ZyLf9ECb8I9ykxo base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB directory-1.3.6.2
    filepath-1.4.2.2 haskell-src-exts-1.23.1-7pI9mgFOriPBpdSkEbBhCA
    monad-dijkstra-0.1.1.5-HQqmbulwVR08yPXJ3lEdhq mtl-2.2.2
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-47hukrr2IXRFDwJY5DTAr2
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floskell-0.10.8-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-EHU1ozUVMWzANl5Mh1COo6
key:                  floskell-0.10.8-EHU1ozUVMWzANl5Mh1COo6
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  1bfc61a3d0a86b5ac39f305dcb8fb1be
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-EHU1ozUVMWzANl5Mh1COo6
depends:
    aeson-2.1.2.1-7MxCVi0kerx5YLDSk2pLUu
    attoparsec-0.14.4-6bGZjP6ZyLf9ECb8I9ykxo base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB directory-1.3.6.2
    filepath-1.4.2.2 haskell-src-exts-1.23.1-7pI9mgFOriPBpdSkEbBhCA
    monad-dijkstra-0.1.1.5-HQqmbulwVR08yPXJ3lEdhq mtl-2.2.2
    text-1.2.5.0 transformers-0.5.6.2
    unordered-containers-0.2.20-47hukrr2IXRFDwJY5DTAr2
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
